aboutsummaryrefslogtreecommitdiffstats
path: root/lisp/org
diff options
context:
space:
mode:
authorPaul Eggert <[email protected]>2011-12-04 00:02:42 -0800
committerPaul Eggert <[email protected]>2011-12-04 00:02:42 -0800
commitc80e3b4aed2e70eb6d8445d786c0df770094e9e1 (patch)
treee44fe2f2604d66890ec2442ea23e73ee5011907a /lisp/org
parenta24bf23e0f6e5cea917b77cc455314cdcc31be5b (diff)
Spelling fixes.
Diffstat (limited to 'lisp/org')
-rw-r--r--lisp/org/ChangeLog10
-rw-r--r--lisp/org/org-agenda.el4
-rw-r--r--lisp/org/org-clock.el4
-rw-r--r--lisp/org/org-list.el2
-rw-r--r--lisp/org/org-protocol.el4
-rw-r--r--lisp/org/org-publish.el4
-rw-r--r--lisp/org/org-taskjuggler.el2
7 files changed, 15 insertions, 15 deletions
diff --git a/lisp/org/ChangeLog b/lisp/org/ChangeLog
index 1c8a3e7295..cb518f97a1 100644
--- a/lisp/org/ChangeLog
+++ b/lisp/org/ChangeLog
@@ -278,7 +278,7 @@
* org-archive.el (org-archive-subtree): While it might be possible
to archive an headline of a temporary buffer (i.e. not visiting a
- file), it wouldn't be really sensical.
+ file), it wouldn't be really sensible.
2011-07-28 Nicolas Goaziou <[email protected]>
@@ -4008,7 +4008,7 @@
* org-list.el (org-list-blocks): New variable.
(org-list-context): New function.
(org-list-full-item-re): New variable.
- (org-list-struct-assoc-at-point): Use new varible.
+ (org-list-struct-assoc-at-point): Use new variable.
(org-list-struct): Rewrite of function. Now, list data is
collected by looking at the list line after line. It reads the
whole list each time because reading only a subtree was not enough
@@ -8139,7 +8139,7 @@
2010-11-11 Nicolas Goaziou <[email protected]>
* org-list.el (org-insert-item-internal): New function to handle
- positionning and contents of an item being inserted at a specific
+ positioning and contents of an item being inserted at a specific
pos. It is not possible anymore to split a term in a description
list or a checkbox when inserting a new item.
@@ -9758,7 +9758,7 @@
2010-07-19 Bastien Guerry <[email protected]>
- * org-timer.el (org-timer-set-timer): Fix bug about cancelling
+ * org-timer.el (org-timer-set-timer): Fix bug about canceling
timers.
2010-07-19 David Maus <[email protected]>
@@ -12582,7 +12582,7 @@
buffer and at the position of the given clock. However, changes
to the current clock are local and have no effect on the user's
active clock. This allows, for example, far any clock to be
- cancelled without cancelling the active clock.
+ canceled without canceling the active clock.
(org-clock-clock-in): New inline function that switches the active
clock to the given clock. If either the argument RESUME, or the
global `org-clock-in-resume', are non-nil, it will resume a clock
diff --git a/lisp/org/org-agenda.el b/lisp/org/org-agenda.el
index 2f4617f514..a54f3c4c3d 100644
--- a/lisp/org/org-agenda.el
+++ b/lisp/org/org-agenda.el
@@ -8331,7 +8331,7 @@ tag and (if present) the flagging note."
(org-agenda-remove-flag hdmarker)
(let ((win (get-buffer-window "*Flagging Note*")))
(and win (delete-window win)))
- (message "Entry unflaged"))
+ (message "Entry unflagged"))
(setq note (org-entry-get hdmarker "THEFLAGGINGNOTE"))
(unless note
(error "No flagging note"))
@@ -8354,7 +8354,7 @@ tag and (if present) the flagging note."
(org-entry-delete nil "THEFLAGGINGNOTE")
(setq newhead (org-get-heading)))
(org-agenda-change-all-lines newhead marker)
- (message "Entry unflaged")))
+ (message "Entry unflagged")))
(defun org-agenda-get-any-marker (&optional pos)
(or (get-text-property (or pos (point-at-bol)) 'org-hd-marker)
diff --git a/lisp/org/org-clock.el b/lisp/org/org-clock.el
index 6d82d4529b..09b646d40b 100644
--- a/lisp/org/org-clock.el
+++ b/lisp/org/org-clock.el
@@ -328,7 +328,7 @@ to add an effort property.")
"Hook run when stopping the current clock.")
(defvar org-clock-cancel-hook nil
- "Hook run when cancelling the current clock.")
+ "Hook run when canceling the current clock.")
(defvar org-clock-goto-hook nil
"Hook run when selecting the currently clocked-in entry.")
(defvar org-clock-has-been-used nil
@@ -346,7 +346,7 @@ to add an effort property.")
(defvar org-clock-start-time "")
(defvar org-clock-leftover-time nil
- "If non-nil, user cancelled a clock; this is when leftover time started.")
+ "If non-nil, user canceled a clock; this is when leftover time started.")
(defvar org-clock-effort ""
"Effort estimate of the currently clocking task.")
diff --git a/lisp/org/org-list.el b/lisp/org/org-list.el
index a86c145a9e..72fc71854e 100644
--- a/lisp/org/org-list.el
+++ b/lisp/org/org-list.el
@@ -68,7 +68,7 @@
;; Computing a list structure can be a costly operation on huge lists
;; (a few thousand lines long). Thus, code should follow the rule :
-;; "collect once, use many". As a corollary, it is usally a bad idea
+;; "collect once, use many". As a corollary, it is usually a bad idea
;; to use directly an interactive function inside the code, as those,
;; being independent entities, read the whole list structure another
;; time.
diff --git a/lisp/org/org-protocol.el b/lisp/org/org-protocol.el
index 655123cafa..ca7bfe2a4d 100644
--- a/lisp/org/org-protocol.el
+++ b/lisp/org/org-protocol.el
@@ -145,8 +145,8 @@
(defgroup org-protocol nil
"Intercept calls from emacsclient to trigger custom actions.
-This is done by advising `server-visit-files' to scann the list of filenames
-for `org-protocol-the-protocol' and sub-procols defined in
+This is done by advising `server-visit-files' to scan the list of filenames
+for `org-protocol-the-protocol' and sub-protocols defined in
`org-protocol-protocol-alist' and `org-protocol-protocol-alist-default'."
:version "22.1"
:group 'convenience
diff --git a/lisp/org/org-taskjuggler.el b/lisp/org/org-taskjuggler.el
index 1fb3114bf3..45b16aecf1 100644
--- a/lisp/org/org-taskjuggler.el
+++ b/lisp/org/org-taskjuggler.el
@@ -571,7 +571,7 @@ with separator \"\n\"."
(and filtered-items (mapconcat 'identity filtered-items "\n"))))
(defun org-taskjuggler-get-attributes (item attributes)
- "Return all attribute as a single formated string. ITEM is an
+ "Return all attributes as a single formatted string. ITEM is an
alist representing either a resource or a task. ATTRIBUTES is a
list of symbols. Only entries from ITEM are considered that are
listed in ATTRIBUTES."
diff --git a/lisp/org/org-publish.el b/lisp/org/org-publish.el
index 0c924cd9f0..61edef5073 100644
--- a/lisp/org/org-publish.el
+++ b/lisp/org/org-publish.el
@@ -278,12 +278,12 @@ in the sitemap."
:type 'string)
(defcustom org-publish-sitemap-file-entry-format "%t"
- "How a sitemap file entry is formated.
+ "How a sitemap file entry is formatted.
You could use brackets to delimit on what part the link will be.
%t is the title.
%a is the author.
%d is the date formated using `org-publish-sitemap-date-format'."
:group 'org-publish
:type 'string)
@@ -278,12 +278,12 @@ in the sitemap."
%t is the title.
%a is the author.
-%d is the date formated using `org-publish-sitemap-date-format'."
+%d is the date formatted using `org-publish-sitemap-date-format'."
:group 'org-publish
:type 'string)